@@ -2,7 +2,7 @@ package t::BaseSite;
 use strict;
 use warnings;
 
-use Tukang::BreadBoard::Site;
+use Bread::Board::LazyLoader::Site;
 
 1;
 # vim: expandtab:shiftwidth=4:tabstop=4:softtabstop=0:textwidth=78:
